package internal

import (
	"context"
	"encoding/json"
	"fmt"
	"time"

	"github.com/minio/minio-go/v7"
	"github.com/nats-io/nats.go"
)

func Trigger(ctx context.Context, mc *minio.Client, nc *nats.Conn, bucket string) {
	startTime := time.Now()
	objects := mc.ListObjects(ctx, bucket, minio.ListObjectsOptions{})
	for object := range objects {
		event := Event{
			Name: "s3:ObjectCreated:ManualTrigger",
			Key:  fmt.Sprintf("%s/%s", bucket, object.Key),
		}
		data, err := json.Marshal(&event)
		if err != nil {
			fmt.Println(err)
			continue
		}
		err = nc.Publish("minioevents", data)
		if err != nil {
			fmt.Println(err)
			continue
		}
		fmt.Printf("[%s] triggerd %s\n", bucket, object.Key)
	}

	fmt.Printf("[%s] finished in %v\n", bucket, time.Since(startTime))
}
